================================
Duplicate & Anonymous File Names
================================

Files within tape images may have no name or the same name as other
files. To identify a specific instance of a file a suffix is added to
the second and later occurrences. For example, if there are two files
named ``FILE`` then the second one is addressable as ``FILE~1``.

The first unnamed file must be addressed as ``~`` to distinguish it
from the entire image.


